"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.feesModel = exports.putMerchantsBankInfo = exports.bankInfoModel = exports.infoModel = exports.addressesModel = exports.putContactsModel = exports.contactsModel = exports.partnersModel = void 0;

var _slingHelpers = require("sling-helpers");

const partnersModel = data => {
  const modeledData = data.map(item => ({
    name: item.name,
    email: item.email,
    rg: item.rg,
    cpf: item.cpf
  }));
  return modeledData;
};

exports.partnersModel = partnersModel;

const contactsModel = data => data;

exports.contactsModel = contactsModel;

const putContactsModel = data => {
  const modeledData = {
    name: data.name,
    typeId: Number(data.typeId),
    email: data.email,
    phone: (0, _slingHelpers.replaceNonDigits)(data.phone),
    mobilePhone: (0, _slingHelpers.replaceNonDigits)(data.mobilePhone)
  };
  return modeledData;
};

exports.putContactsModel = putContactsModel;

const addressesModel = data => {
  const modeledData = data.map(item => ({
    description: item.typeName,
    uf: item.stateName,
    city: item.cityName,
    street: item.streetName,
    number: item.streetNumber,
    complement: item.complement,
    neighborhood: item.neighborhood
  }));
  return modeledData;
};

exports.addressesModel = addressesModel;

const infoModel = (data, stonecode) => {
  const modeledData = [{
    stonecode,
    cnpj: data.document,
    companyName: data.companyName,
    fantasyName: data.fantasyName,
    mccDescription: data.mccDescription
  }];
  return modeledData;
};

exports.infoModel = infoModel;

const bankInfoModel = responses => {
  const [availableBanks, banks] = responses;
  const modeledData = {
    banks: banks.data,
    availableBanks: availableBanks.data
  };
  modeledData.banks = modeledData.banks.reduce((result, current) => {
    const repeatedAccountNumbers = result.map(item => item.accountNumber);
    const repeatedAgencyNumbers = result.map(item => item.agencyNumber);
    const repeatedBankIds = result.map(item => item.bankId);

    if (repeatedAccountNumbers.includes(current.accountNumber) && repeatedAgencyNumbers.includes(current.agencyNumber) && repeatedBankIds.includes(current.bankId)) {
      return result;
    }

    return [...result, current];
  }, []);
  return modeledData;
};

exports.bankInfoModel = bankInfoModel;

const putMerchantsBankInfo = data => {
  const modeledPayload = {
    accountNumber: data.accountNumber,
    accountNumberVerificationCode: data.accountNumberVerificationCode,
    agencyNumber: data.agencyNumber,
    agencyNumberVerificationCode: data.agencyNumberVerificationCode,
    bankId: Number(data.bankId),
    statusId: Number(data.statusId),
    typeId: Number(data.typeId),
    centralizedPayment: data.centralizedPayment
  };
  return modeledPayload;
};

exports.putMerchantsBankInfo = putMerchantsBankInfo;

const feesModel = ([transactionProfilesResp, cardBrandsResp, merchantFeesResp]) => {
  const byTransactionProfileId = id => item => item.transactionProfileId !== id;

  const byCardBrandIdOf = item => cardBrand => cardBrand.id === item.cardBrandId;

  const byTransactionProfileIdOf = item => transactionProfile => transactionProfile.id === item.transactionProfileId;

  const boletoId = 10;
  const transactionProfiles = transactionProfilesResp.data;
  const cardBrands = cardBrandsResp.data;
  const merchantFees = merchantFeesResp.data.filter(byTransactionProfileId(boletoId)).map(merchantFee => ({ ...merchantFee,
    cardBrandName: cardBrands.find(byCardBrandIdOf(merchantFee)).name,
    transactionProfileName: transactionProfiles.find(byTransactionProfileIdOf(merchantFee)).name
  }));
  return merchantFees;
};

exports.feesModel = feesModel;