import * as merchantService from '../../core/services/merchantService.js';
import * as merchantModel from '../../models/merchantModels.js';
import * as transactionsService from '../../core/services/transactionsService.js';

export const getMerchantContacts = (requestParams, instance) => (dispatch) => {
  merchantService.getContacts(requestParams, instance).then((response) => {
    dispatch({
      type: 'GET_MERCHANT_CONTACTS',
      data: merchantModel.contactsModel(response.data),
    });
  });
};

export const putMerchantContacts = (requestParams, instance) => (dispatch) => {
  merchantService.putContacts(requestParams, instance).then((response) => {
    dispatch({
      type: 'PUT_MERCHANT_CONTACTS',
      data: response.data,
    });
  });
};

export const getMerchantPartners = (requestParams, instance) => (dispatch) => {
  merchantService.getPartners(requestParams, instance).then((response) => {
    dispatch({
      type: 'GET_MERCHANT_PARTNERS',
      data: merchantModel.partnersModel(response),
    });
  });
};

export const getMerchantAddresses = (requestParams, instance) => (dispatch) => {
  merchantService.getAddresses(requestParams, instance).then((response) => {
    dispatch({
      type: 'GET_MERCHANT_ADDRESSES',
      data: merchantModel.addressesModel(response.data),
    });
  });
};

export const getMerchantInfo = (requestParams, instance) => (dispatch) => {
  merchantService.getInfo(requestParams, instance).then((response) => {
    dispatch({
      type: 'GET_MERCHANT_INFO',
      data: merchantModel.infoModel(response.data, requestParams.stonecode),
    });
  });
};

export const patchMerchantInfo = (requestParams, instance) => (dispatch) => {
  merchantService.patchInfo(requestParams, instance).then((response) => {
    dispatch({
      type: 'PATCH_MERCHANT_FANTASY_NAME',
      data: response.data.fantasyName,
    });
  });
};

export const getMerchantBankInfo = (requestParams, instance) => (dispatch) => {
  const promises = [
    merchantService.getAvailableBanks(requestParams, instance),
    merchantService.getBankInfo(requestParams, instance),
  ];

  Promise.all(promises)
    .then((responses) => {
      dispatch({
        type: 'GET_MERCHANT_BANK_INFO',
        data: merchantModel.bankInfoModel(responses),
      });
    });
};

export const updateBankAccounts = (requestParams, instance) => (dispatch) => {
  merchantService.putBankAccounts(requestParams, instance).then((response) => {
    dispatch({
      type: 'PUT_MERCHANT_BANK_INFO',
      data: response.data,
    });
  });
};

export const getMerchantFees = (requestParams, instance) => (dispatch) => {
  const promises = [
    transactionsService.getTransactionProfiles(requestParams, instance),
    transactionsService.getBrands(requestParams, instance),
    merchantService.getFees(requestParams, instance),
  ];
  Promise.all(promises)
    .then((responses) => {
      dispatch({
        type: 'GET_MERCHANT_FEES',
        data: merchantModel.feesModel(responses),
      });
    });
};
