import * as paymentsService from '../../core/services/paymentsService.js';
import * as transactionsService from '../../core/services/transactionsService.js';
import * as paymentsModel from '../../models/paymentsModels.js';

const {
  getProductTypes,
  getBrands,
} = transactionsService;

const {
  getPaymentDetailsByWalletTypeId,
  getPaymentDetails,
  getPaymentStatus,
  getPaymentOperations,
  getPaymentWalletTypes,
  getPaymentOperationsCategories,
} = paymentsService;

const {
  paymentsCalendarModel,
  paymentDetailsModel,
  paymentDetailsByWalletTypeIdModel,
} = paymentsModel;

export const getCalendarPaymentsInfo =
  (requestParams, instance) => (dispatch) => {
    const promises = [
      getPaymentDetails({ ...requestParams, crossbalance: true }, instance),
      getPaymentStatus(requestParams, instance),
    ];

    Promise.all(promises)
      .then((responses) => {
        dispatch({
          type: 'GET_PAYMENTS_CALENDAR_INFO',
          data: paymentsCalendarModel(responses),
        });
      });
  };

export const getPaymentDetailsInfo =
  (requestParams, instance) => (dispatch) => {
    const promises = [
      getPaymentDetails({ ...requestParams, crossbalance: true }, instance),
      getPaymentWalletTypes(requestParams, instance),
      getBrands(requestParams, instance),
      getProductTypes(requestParams, instance),
    ];
    Promise.all(promises)
      .then((responses) => {
        dispatch({
          type: 'GET_PAYMENT_DETAILS_INFO',
          data: paymentDetailsModel(responses),
        });
      });
  };

export const getPaymentDetailsInfoByWalletTypeId =
  (requestParams, instance) => (dispatch) => {
    const promises = [
      getPaymentDetailsByWalletTypeId(requestParams, instance),
      getPaymentWalletTypes(requestParams, instance),
      getPaymentOperationsCategories(requestParams, instance),
      getBrands(requestParams, instance),
      getProductTypes(requestParams, instance),
    ];
    Promise.all(promises)
      .then((responses) => {
        dispatch({
          type: 'GET_PAYMENT_DETAILS_INFO_BY_WALLET_TYPE_ID',
          data: paymentDetailsByWalletTypeIdModel(responses),
        });
      });
  };

export const getPaymentOperationsInfo =
  (requestParameters, instance) => (dispatch) => {
    const promises = [
      getPaymentOperations(requestParameters, instance),
      getPaymentStatus(requestParameters, instance),
      getPaymentOperationsCategories(requestParameters, instance),
      getProductTypes(requestParameters, instance),
    ];
    Promise.all(promises)
      .then((responses) => {
        dispatch({
          type: 'GET_PAYMENT_OPERATIONS_INFO',
          data: paymentsModel.paymentOperationsModel(responses),
        });
      });
  };

export const getPaymentWalletTypesInfo =
  (requestParameters, instance) => (dispatch) => {
    paymentsService
      .getPaymentWalletTypes(requestParameters, instance)
      .then((response) => {
        dispatch({
          type: 'GET_PAYMENT_WALLET_TYPES',
          data: paymentsModel.paymentsWalletsTypesModel(response),
        });
      });
  };

export const getPaymentStatusInfo =
  (requestParameters, instance) => (dispatch) => {
    paymentsService
      .getPaymentStatus(requestParameters, instance)
      .then((response) => {
        dispatch({
          type: 'GET_PAYMENT_STATUS',
          data: paymentsModel.paymentsStatusModel(response),
        });
      });
  };

export const getPaymentOperationsCategoriesInfo =
  (requestParameters, instance) => (dispatch) => {
    paymentsService
      .getPaymentOperationsCategories(requestParameters, instance)
      .then((response) => {
        dispatch({
          type: 'GET_PAYMENT_OPERATIONS_CATEGORIES',
          data: paymentsModel.paymentsOperationsCategoriesModel(response),
        });
      });
  };
