import * as paymentsModels from './paymentsModels';

describe('paymentsModels', () => {
  it('Should return correct Payments Calendar model.', () => {
    const infoData = [{
      data: [
        {
          referenceDate: '2018-04-03T00:00:00.000Z',
          amount: 100,
          settlementStatusId: 1,
          walletTypeId: 2,
        },
        {
          referenceDate: '2018-04-03T00:00:00.000Z',
          amount: 100,
          settlementStatusId: 1,
          walletTypeId: 2,
        },
        {
          referenceDate: '2018-04-04T00:00:00.000Z',
          amount: 100,
          settlementStatusId: 1,
          walletTypeId: 2,
        }],
    },
    {
      data: [
        {
          id: 1,
          name: 'Pendente',
        },
        {
          id: 2,
          name: 'Agendado',
        },
        {
          id: 3,
          name: 'Rejeitado',
        },
        {
          id: 4,
          name: 'Pago',
        },
      ],
    }];


    const modeledData = {
      '2018-04-03': [{
        amount: 200,
        date: '2018-04-03',
        status: 'Pendente',
        settlement_status_id: 1,
      }],
      '2018-04-04': [{
        amount: 100,
        date: '2018-04-04',
        status: 'Pendente',
        settlement_status_id: 1,
      }],
    };

    expect(paymentsModels.paymentsCalendarModel(infoData)).to.be
      .deep.equal(modeledData);
  });

  it('Should return correct Payment Detail Summary model.', () => {
    const infoData = [{
      data: [
        {
          referenceDate: '2018-05-14T00:00:00.000Z',
          amount: 68657,
          walletTypeId: 3,
          settlementStatusId: 4,
        },
        {
          referenceDate: '2018-05-14T00:00:00.000Z',
          amount: 147,
          walletTypeId: 6,
          settlementStatusId: 2,
        },
        {
          referenceDate: '2018-05-14T00:00:00.000Z',
          amount: 98408,
          walletTypeId: 6,
          settlementStatusId: 4,
        },
        {
          referenceDate: '2018-05-14T00:00:00.000Z',
          amount: 677,
          walletTypeId: 12,
          settlementStatusId: 4,
        }],
    },
    {
      data: [
        {
          id: 3,
          name: 'Visa Crédito',
          brandId: 1,
          productTypeId: 2,
        },
        {
          id: 6,
          name: 'Mastercard Crédito',
          brandId: 2,
          productTypeId: 2,
        },
        {
          id: 12,
          name: 'Elo Crédito',
          brandId: 171,
          productTypeId: 2,
        }],
    },
    {
      data: [
        {
          id: 1,
          name: 'Visa',
        },
        {
          id: 2,
          name: 'MasterCard',
        },
        {
          id: 171,
          name: 'Elo',
        }],
    },
    {
      data: [
        {
          id: 1,
          name: 'Débito',
        },
        {
          id: 2,
          name: 'Crédito',
        }],
    }];

    const modeledData = [{
      summary: {
        1: [{
          amount: 68657,
          brandId: 1,
          brandName: 'Visa',
          productType: 'Crédito',
          settlementStatusId: 4,
          walletTypeId: 3,
          name: 'Visa Crédito',
        }],
        2: [{
          amount: 98555,
          brandId: 2,
          brandName: 'MasterCard',
          productType: 'Crédito',
          settlementStatusId: 2,
          walletTypeId: 6,
          name: 'Mastercard Crédito',
        }],
        171: [{
          amount: 677,
          brandId: 171,
          brandName: 'Elo',
          productType: 'Crédito',
          settlementStatusId: 4,
          walletTypeId: 12,
          name: 'Elo Crédito',
        }],
      },
      total: [
        {
          amount: 167889,
          name: 'Saldo',
        },
        {
          amount: 167742,
          name: 'Total pago',
        },
      ],
    }];

    expect(paymentsModels.paymentDetailsModel(infoData)).to.be
      .deep.equal(modeledData);
  });

  it('Should return correct Payments Wallet Types model.', () => {
    const infoData = [
      {
        id: 1,
        name: 'Default',
        brandId: 9999,
        productTypeId: 20,
      },
      {
        id: 2,
        name: 'VisaDebit',
        brandId: 1,
        productTypeId: 1,
      },
      {
        id: 3,
        name: 'VisaCredit',
        brandId: 1,
        productTypeId: 2,
      },
      {
        id: 4,
        name: 'VisaPrePayment',
        brandId: 1,
        productTypeId: 20,
      }];

    const modeledData = [
      {
        id: 1,
        name: 'Default',
        brandId: 9999,
        productTypeId: 20,
      },
      {
        id: 2,
        name: 'VisaDebit',
        brandId: 1,
        productTypeId: 1,
      },
      {
        id: 3,
        name: 'VisaCredit',
        brandId: 1,
        productTypeId: 2,
      },
      {
        id: 4,
        name: 'VisaPrePayment',
        brandId: 1,
        productTypeId: 20,
      }];

    expect(paymentsModels.paymentsWalletsTypesModel(infoData)).to.be
      .deep.equal(modeledData);
  });

  it('Should model payment details by walletTypeId correctly.', () => {
    const infoData = [{
      data:
        [
          {
            movementCategoryId: 14,
            amount: 3623.91,
            referenceDate: '2018-06-01T00:00:00.000Z',
            settlementStatusId: 4,
            walletTypeId: 2,
          },
          {
            movementCategoryId: 30,
            amount: -3623.91,
            referenceDate: '2018-06-01T00:00:00.000Z',
            settlementStatusId: 4,
            walletTypeId: 2,
          },
        ],
    },
    {
      data: [
        {
          id: 2,
          name: 'Visa Débito',
          brandId: 1,
          productTypeId: 1,
        },
        {
          id: 3,
          name: 'Visa Crédito',
          brandId: 1,
          productTypeId: 2,
        }],
    },
    {
      data: [
        {
          id: 14,
          name: 'Venda',
          isTransactionalMovement: 1,
          transactionStatusId: 1,
        },
        {
          id: 30,
          name: 'Split',
          isTransactionalMovement: 1,
          transactionStatusId: 6,
        },
      ],
    },
    {
      data: [
        {
          id: 1,
          name: 'Visa',
        },
        {
          id: 2,
          name: 'MasterCard',
        },
      ],
    },
    {
      data: [
        {
          id: 1,
          name: 'Débito',
        },
        {
          id: 2,
          name: 'Crédito',
        },
      ],
    },
    ];

    const modeledData = [
      {
        amount: 3623.91,
        brandId: 1,
        productType: 'Débito',
        walletTypeName: 'Visa Débito',
        movementCategory: 'Venda',
        movementCategoryId: 14,
        brandName: 'Visa',
      },
      {
        amount: -3623.91,
        brandId: 1,
        productType: 'Débito',
        walletTypeName: 'Visa Débito',
        movementCategory: 'Split',
        movementCategoryId: 30,
        brandName: 'Visa',
      },
    ];

    const expectedTotal = [
      {
        name: 'Saldo final',
        amount: 0,
      },
    ];

    const actual = paymentsModels.paymentDetailsByWalletTypeIdModel(infoData);
    expect(actual).to.be.deep.equal(modeledData);
    expect(actual.total).to.be.deep.equal(expectedTotal);
  });

  it('Should group and sum values by movementCategoryId.', () => {
    const infoData = [{
      data:
        [
          {
            movementCategoryId: 14,
            amount: 679.16,
            referenceDate: '2018-06-21T00:00:00.000Z',
            settlementStatusId: 4,
            walletTypeId: 3,
          },
          {
            movementCategoryId: 30,
            amount: -679.16,
            referenceDate: '2018-06-21T00:00:00.000Z',
            settlementStatusId: 4,
            walletTypeId: 3,
          },
          {
            movementCategoryId: 14,
            amount: 500.01,
            referenceDate: '2018-06-22T00:00:00.000Z',
            settlementStatusId: 1,
            walletTypeId: 3,
          },
        ],
    },
    {
      data: [
        {
          id: 2,
          name: 'Visa Débito',
          brandId: 1,
          productTypeId: 1,
        },
        {
          id: 3,
          name: 'Visa Crédito',
          brandId: 1,
          productTypeId: 2,
        }],
    },
    {
      data: [
        {
          id: 14,
          name: 'Venda',
          isTransactionalMovement: 1,
          transactionStatusId: 1,
        },
        {
          id: 30,
          name: 'Split',
          isTransactionalMovement: 1,
          transactionStatusId: 6,
        },
      ],
    },
    {
      data: [
        {
          id: 1,
          name: 'Visa',
        },
        {
          id: 2,
          name: 'MasterCard',
        },
      ],
    },
    {
      data: [
        {
          id: 1,
          name: 'Débito',
        },
        {
          id: 2,
          name: 'Crédito',
        },
      ],

    }];

    const modeledData = [
      {
        amount: 1179.17,
        brandId: 1,
        productType: 'Crédito',
        walletTypeName: 'Visa Crédito',
        movementCategory: 'Venda',
        movementCategoryId: 14,
        brandName: 'Visa',
      },
      {
        amount: -679.16,
        brandId: 1,
        productType: 'Crédito',
        walletTypeName: 'Visa Crédito',
        movementCategory: 'Split',
        movementCategoryId: 30,
        brandName: 'Visa',
      },
    ];

    const expectedTotal = [
      {
        name: 'Saldo final',
        amount: 500.01,
      },
    ];

    const actual = paymentsModels.paymentDetailsByWalletTypeIdModel(infoData);
    expect(actual).to.be.deep.equal(modeledData);
    expect(actual.total).to.be.deep.equal(expectedTotal);
  });

  it('Should format values by paymentOperationsModel', () => {
    const initialData = [{
      page: 0,
      pageSize: 30,
      total: 63,
      data: [
        {
          movementId: 2044317305,
          confirmedTransactionId: 697812532,
          affiliationCode: 143933007,
          document: '25.176.477/0001-53',
          legalName: 'HIBISCO ALIMENTOS LTDA',
          fantasyName: 'Jojo To Go II',
          movementCategoryId: 14,
          operationDate: '2018-01-22T11:59:36.000Z',
          referenceDate: '2018-01-23T00:00:00.000Z',
          productTypeId: 1,
          installmentNumber: 1,
          installments: 1,
          brandId: 2,
          transactionKey: '12280988458205',
          maskedPan: '549167******6733',
          operationCode: 1,
          grossAmount: 43,
          feePrePayment: 0,
          merchantDiscountRate: 0.8127,
          netAmount: 42.1873,
          settlementStatusId: 4,
        },
      ],
    },
    {
      data: [
        {
          id: 1,
          name: 'Pendente',
        },
        {
          id: 2,
          name: 'Agendado',
        },
        {
          id: 3,
          name: 'Rejeitado',
        },
        {
          id: 4,
          name: 'Pago',
        },
      ],
    },
    {
      data: [
        {
          id: 14,
          name: 'Venda',
          isTransactionalMovement: 1,
          transactionStatusId: 1,
        },
      ],
    },
    {
      data: [
        {
          id: 1,
          name: 'Débito',
        },
        {
          id: 2,
          name: 'Crédito',
        },
      ],
    }];

    const modeledData = {
      total: 63,
      data: [
        {
          operation_date: '2018-01-22T11:59:36.000Z',
          reference_date: '2018-01-23T00:00:00.000Z',
          category: 'Venda',
          gross_amount: 43,
          brand_id: 2,
          transaction_key: '12280988458205',
          net_amount: 42.1873,
          installment_number: 1,
          settlement_status_id: 4,
          status: 'Pago',
          product: 'Débito 1x',
        },
      ],
    };

    expect(paymentsModels.paymentOperationsModel(initialData)).to.be
      .deep.equal(modeledData);
  });
});
