import sinon from 'sinon';
import { service as addressService } from './addresses.js';

const urlParams = { affiliationCode: '321321321' };

describe('Affiliation Addresses Module', () => {
  it('Should have methods after initialization.', () => {
    const service = addressService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = addressService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = addressService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/affiliation/merchants/321321321/addresses');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = addressService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
