import sinon from 'sinon';
import { service as forgotPasswordService } from './forgotPassword.js';
import { forgotPasswordInterface } from './forgotPasswordInterface.js';

const urlParams = {};

describe('Credentials Forgot Password Module', () => {
  it('Should have methods after initialization.', () => {
    const service = forgotPasswordService();
    expect(service.post).to.be.a('function');
  });

  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = forgotPasswordService(postRequest);

    service.post(urlParams, forgotPasswordInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (urlString) => {
      spy(urlString);
      return () => {};
    };

    const service = forgotPasswordService(postRequest);

    service.post(urlParams, forgotPasswordInterface);

    expect(spy).to.have.been.calledOnceWith('v0/forgot-password');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = forgotPasswordService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });
});
