import sinon from 'sinon';
import { service as bankAccounts } from './bankAccounts.js';

const urlParams = { affiliationCode: '321321321' };

describe('Partial Lock Bank Accounts Module', () => {
  it('Should have methods after initialization.', () => {
    const service = bankAccounts();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = bankAccounts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = bankAccounts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/acquirer/merchants/321321321/bank-accounts');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = bankAccounts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
