import sinon from 'sinon';
import { service as creditLockContracts } from './creditLockContracts.js';

const urlParams = {
  document: '321321321',
  status: 'pendingApproval',
};

const urlParams2 = {
  document: '5327056609',
};

describe('Partial Lock Credit Lock Contracts Module', () => {
  it('Should have methods after initialization.', () => {
    const service = creditLockContracts();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = creditLockContracts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = creditLockContracts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/credit-lock-contracts?document=321321321' +
        '&status=pendingApproval');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = creditLockContracts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });

  it('Should call get request sent only with doc number.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = creditLockContracts(getRequest);

    service.get(urlParams2);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request sent with doc and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams2));
      return () => {};
    };

    const service = creditLockContracts(getRequest);

    service.get(urlParams2);

    expect(spy).to.have.been
      .calledWith('v0/merchants/credit-lock-contracts?document=5327056609');
  });

  it('Should call get request with only document number.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = creditLockContracts(getRequest);

    service.get(urlParams2);

    expect(spy).to.have.been.calledWith(urlParams2);
  });
});
