import sinon from 'sinon';
import { service as receivablesFilesService } from './receivablesFiles.js';
import { receivablesFilesInterface } from './receivablesFilesInterface.js';

const urlParams = {
  document: '11111111111111',
};

describe('Partial Lock Receivables Files Module', () => {
  it('Should have methods after initialization.', () => {
    const service = receivablesFilesService();
    expect(service.post).to.be.a('function');
  });

  it('Should call post request.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = receivablesFilesService(postRequest);

    service.post(urlParams, receivablesFilesInterface);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call post request and return a valid URL.', () => {
    const spy = sinon.spy();

    const postRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = receivablesFilesService(postRequest);

    service.post(urlParams, receivablesFilesInterface);

    expect(spy).to.have.been
      .calledOnceWith('v0/merchants/11111111111111/receivables-files');
  });

  it('Should call post request with valid params.', () => {
    const spy = sinon.spy();

    const postRequest = () => spy;

    const service = receivablesFilesService(postRequest);

    service.post(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });
});
