import sinon from 'sinon';

import { service as searchService } from './search.js';

const params = {
  postalCode: '11111111',
};

describe('Details Module', () => {
  it('Should have methods after initialization.', () => {
    const service = searchService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = searchService(getRequest);

    service.get(params);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(params));
      return () => {};
    };

    const service = searchService(getRequest);

    service.get(params);

    expect(spy).to.have.been
      .calledWith('v0/postal-code/11111111');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = searchService(getRequest);

    service.get(params);

    expect(spy).to.have.been.calledWith(params);
  });
});
